==> sylpheed-claws-gtk2_2.5.0~rc3.orig.tar.gz: sylpheed-claws-gtk2-2.5.0~rc3/src/quote_fmt_parse.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SHOW_NEWSGROUPS = 258,
     SHOW_DATE = 259,
     SHOW_FROM = 260,
     SHOW_FULLNAME = 261,
     SHOW_FIRST_NAME = 262,
     SHOW_LAST_NAME = 263,
     SHOW_SENDER_INITIAL = 264,
     SHOW_SUBJECT = 265,
     SHOW_TO = 266,
     SHOW_MESSAGEID = 267,
     SHOW_PERCENT = 268,
     SHOW_CC = 269,
     SHOW_REFERENCES = 270,
     SHOW_MESSAGE = 271,
     SHOW_QUOTED_MESSAGE = 272,
     SHOW_BACKSLASH = 273,
     SHOW_TAB = 274,
     SHOW_QUOTED_MESSAGE_NO_SIGNATURE = 275,
     SHOW_MESSAGE_NO_SIGNATURE = 276,
     SHOW_EOL = 277,
     SHOW_QUESTION_MARK = 278,
     SHOW_EXCLAMATION_MARK = 279,
     SHOW_PIPE = 280,
     SHOW_OPARENT = 281,
     SHOW_CPARENT = 282,
     QUERY_DATE = 283,
     QUERY_FROM = 284,
     QUERY_FULLNAME = 285,
     QUERY_SUBJECT = 286,
     QUERY_TO = 287,
     QUERY_NEWSGROUPS = 288,
     QUERY_MESSAGEID = 289,
     QUERY_CC = 290,
     QUERY_REFERENCES = 291,
     QUERY_NOT_DATE = 292,
     QUERY_NOT_FROM = 293,
     QUERY_NOT_FULLNAME = 294,
     QUERY_NOT_SUBJECT = 295,
     QUERY_NOT_TO = 296,
     QUERY_NOT_NEWSGROUPS = 297,
     QUERY_NOT_MESSAGEID = 298,
     QUERY_NOT_CC = 299,
     QUERY_NOT_REFERENCES = 300,
     INSERT_FILE = 301,
     INSERT_PROGRAMOUTPUT = 302,
     INSERT_USERINPUT = 303,
     OPARENT = 304,
     CPARENT = 305,
     CHARACTER = 306,
     SHOW_DATE_EXPR = 307,
     SET_CURSOR_POS = 308
   };
#endif
/* Tokens.  */
#define SHOW_NEWSGROUPS 258
#define SHOW_DATE 259
#define SHOW_FROM 260
#define SHOW_FULLNAME 261
#define SHOW_FIRST_NAME 262
#define SHOW_LAST_NAME 263
#define SHOW_SENDER_INITIAL 264
#define SHOW_SUBJECT 265
#define SHOW_TO 266
#define SHOW_MESSAGEID 267
#define SHOW_PERCENT 268
#define SHOW_CC 269
#define SHOW_REFERENCES 270
#define SHOW_MESSAGE 271
#define SHOW_QUOTED_MESSAGE 272
#define SHOW_BACKSLASH 273
#define SHOW_TAB 274
#define SHOW_QUOTED_MESSAGE_NO_SIGNATURE 275
#define SHOW_MESSAGE_NO_SIGNATURE 276
#define SHOW_EOL 277
#define SHOW_QUESTION_MARK 278
#define SHOW_EXCLAMATION_MARK 279
#define SHOW_PIPE 280
#define SHOW_OPARENT 281
#define SHOW_CPARENT 282
#define QUERY_DATE 283
#define QUERY_FROM 284
#define QUERY_FULLNAME 285
#define QUERY_SUBJECT 286
#define QUERY_TO 287
#define QUERY_NEWSGROUPS 288
#define QUERY_MESSAGEID 289
#define QUERY_CC 290
#define QUERY_REFERENCES 291
#define QUERY_NOT_DATE 292
#define QUERY_NOT_FROM 293
#define QUERY_NOT_FULLNAME 294
#define QUERY_NOT_SUBJECT 295
#define QUERY_NOT_TO 296
#define QUERY_NOT_NEWSGROUPS 297
#define QUERY_NOT_MESSAGEID 298
#define QUERY_NOT_CC 299
#define QUERY_NOT_REFERENCES 300
#define INSERT_FILE 301
#define INSERT_PROGRAMOUTPUT 302
#define INSERT_USERINPUT 303
#define OPARENT 304
#define CPARENT 305
#define CHARACTER 306
#define SHOW_DATE_EXPR 307
#define SET_CURSOR_POS 308




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 477 "quote_fmt_parse.y"
{
	char chr;
	char str[256];
}
/* Line 1529 of yacc.c.  */
#line 160 "quote_fmt_parse.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> sylpheed-claws-gtk2_2.6.0.orig.tar.gz: sylpheed-claws-gtk2-2.6.0/src/quote_fmt_parse.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SHOW_NEWSGROUPS = 258,
     SHOW_DATE = 259,
     SHOW_FROM = 260,
     SHOW_FULLNAME = 261,
     SHOW_FIRST_NAME = 262,
     SHOW_LAST_NAME = 263,
     SHOW_SENDER_INITIAL = 264,
     SHOW_SUBJECT = 265,
     SHOW_TO = 266,
     SHOW_MESSAGEID = 267,
     SHOW_PERCENT = 268,
     SHOW_CC = 269,
     SHOW_REFERENCES = 270,
     SHOW_MESSAGE = 271,
     SHOW_QUOTED_MESSAGE = 272,
     SHOW_BACKSLASH = 273,
     SHOW_TAB = 274,
     SHOW_QUOTED_MESSAGE_NO_SIGNATURE = 275,
     SHOW_MESSAGE_NO_SIGNATURE = 276,
     SHOW_EOL = 277,
     SHOW_QUESTION_MARK = 278,
     SHOW_EXCLAMATION_MARK = 279,
     SHOW_PIPE = 280,
     SHOW_OPARENT = 281,
     SHOW_CPARENT = 282,
     SHOW_ACCOUNT_FULL_NAME = 283,
     SHOW_ACCOUNT_MAIL_ADDRESS = 284,
     SHOW_ACCOUNT_NAME = 285,
     SHOW_ACCOUNT_ORGANIZATION = 286,
     QUERY_DATE = 287,
     QUERY_FROM = 288,
     QUERY_FULLNAME = 289,
     QUERY_SUBJECT = 290,
     QUERY_TO = 291,
     QUERY_NEWSGROUPS = 292,
     QUERY_MESSAGEID = 293,
     QUERY_CC = 294,
     QUERY_REFERENCES = 295,
     QUERY_ACCOUNT_FULL_NAME = 296,
     QUERY_ACCOUNT_ORGANIZATION = 297,
     QUERY_NOT_DATE = 298,
     QUERY_NOT_FROM = 299,
     QUERY_NOT_FULLNAME = 300,
     QUERY_NOT_SUBJECT = 301,
     QUERY_NOT_TO = 302,
     QUERY_NOT_NEWSGROUPS = 303,
     QUERY_NOT_MESSAGEID = 304,
     QUERY_NOT_CC = 305,
     QUERY_NOT_REFERENCES = 306,
     QUERY_NOT_ACCOUNT_FULL_NAME = 307,
     QUERY_NOT_ACCOUNT_ORGANIZATION = 308,
     INSERT_FILE = 309,
     INSERT_PROGRAMOUTPUT = 310,
     INSERT_USERINPUT = 311,
     OPARENT = 312,
     CPARENT = 313,
     CHARACTER = 314,
     SHOW_DATE_EXPR = 315,
     SET_CURSOR_POS = 316
   };
#endif
/* Tokens.  */
#define SHOW_NEWSGROUPS 258
#define SHOW_DATE 259
#define SHOW_FROM 260
#define SHOW_FULLNAME 261
#define SHOW_FIRST_NAME 262
#define SHOW_LAST_NAME 263
#define SHOW_SENDER_INITIAL 264
#define SHOW_SUBJECT 265
#define SHOW_TO 266
#define SHOW_MESSAGEID 267
#define SHOW_PERCENT 268
#define SHOW_CC 269
#define SHOW_REFERENCES 270
#define SHOW_MESSAGE 271
#define SHOW_QUOTED_MESSAGE 272
#define SHOW_BACKSLASH 273
#define SHOW_TAB 274
#define SHOW_QUOTED_MESSAGE_NO_SIGNATURE 275
#define SHOW_MESSAGE_NO_SIGNATURE 276
#define SHOW_EOL 277
#define SHOW_QUESTION_MARK 278
#define SHOW_EXCLAMATION_MARK 279
#define SHOW_PIPE 280
#define SHOW_OPARENT 281
#define SHOW_CPARENT 282
#define SHOW_ACCOUNT_FULL_NAME 283
#define SHOW_ACCOUNT_MAIL_ADDRESS 284
#define SHOW_ACCOUNT_NAME 285
#define SHOW_ACCOUNT_ORGANIZATION 286
#define QUERY_DATE 287
#define QUERY_FROM 288
#define QUERY_FULLNAME 289
#define QUERY_SUBJECT 290
#define QUERY_TO 291
#define QUERY_NEWSGROUPS 292
#define QUERY_MESSAGEID 293
#define QUERY_CC 294
#define QUERY_REFERENCES 295
#define QUERY_ACCOUNT_FULL_NAME 296
#define QUERY_ACCOUNT_ORGANIZATION 297
#define QUERY_NOT_DATE 298
#define QUERY_NOT_FROM 299
#define QUERY_NOT_FULLNAME 300
#define QUERY_NOT_SUBJECT 301
#define QUERY_NOT_TO 302
#define QUERY_NOT_NEWSGROUPS 303
#define QUERY_NOT_MESSAGEID 304
#define QUERY_NOT_CC 305
#define QUERY_NOT_REFERENCES 306
#define QUERY_NOT_ACCOUNT_FULL_NAME 307
#define QUERY_NOT_ACCOUNT_ORGANIZATION 308
#define INSERT_FILE 309
#define INSERT_PROGRAMOUTPUT 310
#define INSERT_USERINPUT 311
#define OPARENT 312
#define CPARENT 313
#define CHARACTER 314
#define SHOW_DATE_EXPR 315
#define SET_CURSOR_POS 316




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 480 "quote_fmt_parse.y"
{
	char chr;
	char str[256];
}
/* Line 1529 of yacc.c.  */
#line 176 "quote_fmt_parse.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
